Test Environment v2.0.12
========================

Overview
--------

.. $include testenv_description.rst

How to use
----------

.. $include testenv_usage.rst

Model data declaration
~~~~~~~~~~~~~~~~~~~~~~

.. $include testenv_usage_model_data_declaration.rst

Magic relationship
~~~~~~~~~~~~~~~~~~

.. $include testenv_usage_magic_relationship.rst

Module test execution session
-----------------------------

Introduction
~~~~~~~~~~~~

.. $include testenv_usage_execution_session.rst

Data values
-----------

.. $include testenv_usage_data_values.rst

company_id
~~~~~~~~~~

.. $include testenv_usage_data_company_id.rst

currency_id
~~~~~~~~~~~

.. $include testenv_usage_data_currency_id.rst

boolean
~~~~~~~

.. $include testenv_usage_data_boolean.rst

char / text
~~~~~~~~~~~

.. $include testenv_usage_data_char.rst

integer / float / monetary
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. $include testenv_usage_data_numeric.rst

date / datetime
~~~~~~~~~~~~~~~

.. $include testenv_usage_data_datetime.rst

many2one
~~~~~~~~

.. $include testenv_usage_data_many2one.rst

one2many / many2many
~~~~~~~~~~~~~~~~~~~~

.. $include testenv_usage_data_2many.rst

binary
~~~~~~

.. $include testenv_usage_data_binary.rst

External reference for many2one, one2many and many2many fields
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. $include testenv_usage_external_reference.rst

Functions
---------

.. $include testenv_usage_functions.rst
